SEPpy Documentation
-----------------------------

This is the documentation for SEPpy.

.. toctree::
   :maxdepth: 2
   :caption: Contents:


..
	Indices and tables
	==================
..
	* :ref:`genindex`
	* :ref:`modindex`
	* :ref:`search`


.. autofunction:: seppy.seppy

